import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

SECRET_KEY = 'django-insecure-ynff)9l#l3xzy$%q)pb24_p#wt#r-dsu$pt%v5jy_gfh4pfzb@'

DEBUG = True

INSTALLED_APPS = (
    "core",
)

MIDDLEWARE_CLASSES = []

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'


from django.core.management import execute_from_command_line
import os, sys

if __name__ == "__main__":
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "core.settings")
    execute_from_command_line(sys.argv)


#!/usr/bin/env python
import os, sys

from django.core.management import execute_from_command_line as django_execute
import django_db_only


def show_usage():
	print("Usage: " + os.path.basename(sys.argv[0]) + " startproject [projectname]")
	return

def execute_from_command_line():

	if len(sys.argv) < 3:
		show_usage()
		sys.exit(1)

	cmd = sys.argv[1]
	if cmd.lower()!="startproject":
		show_usage()
		sys.exit(1)

	projectname = sys.argv[2]

	sys.argv.append("--template")
	templ_path = os.path.join(os.path.dirname(django_db_only.__file__), "conf/project_template")
	sys.argv.append(templ_path)

	django_execute(sys.argv)

	return




from setuptools import setup, find_packages

EXCLUDE_FROM_PACKAGES = [
	'django_db_only.conf.project_template',
]

setup(
	name='django_db_only',
	version='0.0.3',
	description='Django models as standalone app.',
	long_description = open('README.md').read(),
	author='Abror Qodirov',
	author_email='splayerme@gmail.com',
	packages=find_packages(exclude=EXCLUDE_FROM_PACKAGES),
	entry_points={'console_scripts': [
		'django_db_only = django_db_only:execute_from_command_line',
	]},
	url='http://github.com/abrorbekuz/django-db-only',
	include_package_data=True,
	classifiers=[
		"Programming Language :: Python",
		"License :: OSI Approved :: Python Software Foundation License",
		"Development Status :: 3 - Alpha",
		"Operating System :: OS Independent",
		"Framework :: Django",
		"Intended Audience :: Developers",
		"Topic :: Internet :: WWW/HTTP :: Dynamic Content",
	],
	zip_safe=False,


)
